==> deepin-boot-maker_2.0.4.4.orig.tar.xz: deepin-boot-maker-2.0.4.4/src/translations/deepin-boot-maker_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="64"/>
        <source>Failed to call the command %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="66"/>
        <source>Disk Format Error: Please format the disk with FAT32</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="68"/>
        <source>Insufficient Disk Space: Please ensure that the disk has %1 free space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="70"/>
        <source>Disk Mount Error: Please plug in the disk again or reboot the system to retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="72"/>
        <source>Image Uncompress Error: Please check the md5 checksum of the image and ensure the image is complete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="74"/>
        <source>Internal Error</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="117"/>
        <source>Deepin Boot Maker is a simple tool to write system image file into CD/DVD, USB drive and other installation medias.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="119"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="46"/>
        <source>Please select an ISO image file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="68"/>
        <source>Drag an ISO image file and drop it here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="72"/>
        <source>OR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="84"/>
        <source>Select an ISO image file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="102"/>
        <source>Next</source>
        <translation>Kế tiếp</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="156"/>
        <source>Reselect an ISO image file</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="44"/>
        <source>Making</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Making the disk, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Please do not remove the disk or shut down the computer when making</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="39"/>
        <source>Removable Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="108"/>
        <source>Removable disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/main.cpp" line="116"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="86"/>
        <source>Reboot now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Make Successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <translation>Xong</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="122"/>
        <source>The error log will be uploaded automatically with feedback. We can not improve without your feedback and support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="123"/>
        <source>Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Close</source>
        <translation>Đóng lại</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="145"/>
        <source>Sorry, making failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="146"/>
        <source>Making failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="79"/>
        <source>Please select a disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="102"/>
        <source>Formating disk can increase the making success rate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="124"/>
        <source>No available disk found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="136"/>
        <source>Start making</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>The disk data will be completely  deleted by formating, please confirm and continue</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-boot-maker_2.0.4.9.orig.tar.xz: deepin-boot-maker-2.0.4.9/src/translations/deepin-boot-maker_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="64"/>
        <source>Failed to call the command %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="66"/>
        <source>Disk Format Error: Please format the disk with FAT32</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="68"/>
        <source>Insufficient Disk Space: Please ensure that the disk has %1 free space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="70"/>
        <source>Disk Mount Error: Please plug in the disk again or reboot the system to retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="72"/>
        <source>Image Uncompress Error: Please check the md5 checksum of the image and ensure the image is complete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="74"/>
        <source>Internal Error</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="117"/>
        <source>Deepin Boot Maker is a simple tool to write system image file into CD/DVD, USB drive and other installation medias.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="119"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="46"/>
        <source>Please select an ISO image file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="68"/>
        <source>Drag an ISO image file and drop it here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="72"/>
        <source>OR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="84"/>
        <source>Select an ISO image file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="102"/>
        <source>Next</source>
        <translation>Kế tiếp</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="162"/>
        <source>Reselect an ISO image file</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="44"/>
        <source>Making</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Making the disk, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Please do not remove the disk or shut down the computer when making</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="118"/>
        <source>Removable disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/main.cpp" line="116"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="86"/>
        <source>Reboot now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Make Successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <translation>Xong</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="122"/>
        <source>The error log will be uploaded automatically with feedback. We can not improve without your feedback and support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="123"/>
        <source>Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Close</source>
        <translation>Đóng lại</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="145"/>
        <source>Sorry, making failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="146"/>
        <source>Making failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="79"/>
        <source>Please select a disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="102"/>
        <source>Formatting disk can increase the making success rate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="124"/>
        <source>No available disk found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="136"/>
        <source>Start making</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>The disk data will be completely deleted by formatting, please confirm and continue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Format USB flash drive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="233"/>
        <source>All data will be lost during formatting, please back up in advance and then press OK button.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="234"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="235"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
